@@ -1,7 +1,7 @@
 /*
  *  diskspace.c
  *
- *  Copyright (c) 2010-2019 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2010-2021 Pacman Development Team <pacman-dev@archlinux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -359,7 +359,7 @@ static int check_mountpoint(alpm_handle_t *handle, alpm_mountpoint_t *mp)
 }
 
 int _alpm_check_downloadspace(alpm_handle_t *handle, const char *cachedir,
-		size_t num_files, off_t *file_sizes)
+		size_t num_files, const off_t *file_sizes)
 {
 	alpm_list_t *mount_points;
 	alpm_mountpoint_t *cachedir_mp;
